#version 150

#moj_import <minecraft:fog.glsl>
#moj_import <minecraft:hueshift.glsl>

uniform sampler2D Sampler0;

uniform float GameTime;
uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;

in float vertexDistance;
in vec4 vertexColor;
in vec4 lightMapColor;
in vec4 overlayColor;
in vec2 texCoord0;

out vec4 fragColor;

#define GameTimeMultiplier 500.0
#define pi 3.1415926535

void main() {
    vec4 color = texture(Sampler0, texCoord0);
#ifdef ALPHA_CUTOUT
    if (color.a < ALPHA_CUTOUT) {
        discard;
    }
#endif
    color *= vertexColor * ColorModulator;
#ifndef NO_OVERLAY
    color.rgb = mix(overlayColor.rgb, color.rgb, overlayColor.a);
#endif
#ifndef EMISSIVE
    vec4 init = textureLod(Sampler0, texCoord0, 0.0);
    int alpha = int(init.a * 255);

    bool isTransparent = (alpha <= 140 && alpha >= 0);
    float pulse = (sin(GameTime * pi * GameTimeMultiplier) + 1.0) * 0.5;
    float slowPulse = (sin(GameTime * pi * (GameTimeMultiplier / 10)) + 1.0) * 0.5;

    if (isTransparent) {
	if (alpha == 140) {
	    color *= (1.0 - lightMapColor) + lightMapColor;
	}
	if (alpha == 130) {
	    color *= pulse * (1.0 - lightMapColor) + lightMapColor;
	}
	if (alpha == 120) {
	    color.rgb = colorTransition(color.rgb, hueShift(color.rgb, -0.06 * pi) + vec3(0.1, 0.1, 0.1), pulse);
	}
    } else {
	color *= lightMapColor;
    }
#endif
    fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
}
