vec3 hueShift(vec3 color, float hueAdjust) {
    const vec3 kRGBToYPrime = vec3(0.299, 0.587, 0.114);
    const vec3 kRGBToI = vec3(0.596, -0.275, -0.321);
    const vec3 kRGBToQ = vec3(0.212, -0.523, 0.311);
    
    const vec3 kYIQToRGB[3] = vec3[](
        vec3(1.0, 0.956, 0.621), // R
        vec3(1.0, -0.272, -0.647), // G
        vec3(1.0, -1.107, 1.704)  // B
    );

    float YPrime = dot(color, kRGBToYPrime);
    float I = dot(color, kRGBToI);
    float Q = dot(color, kRGBToQ);
    
    float hue = atan(Q, I) + hueAdjust;
    float chroma = length(vec2(I, Q));

    I = chroma * cos(hue);
    Q = chroma * sin(hue);

    vec3 yIQ = vec3(YPrime, I, Q);
    return vec3(dot(yIQ, kYIQToRGB[0]), dot(yIQ, kYIQToRGB[1]), dot(yIQ, kYIQToRGB[2]));
}

vec3 colorTransition(vec3 currentColor, vec3 targetColor, float transitionFactor) {
    return mix(currentColor, targetColor, clamp(transitionFactor, 0.0, 1.0));
}